BenchmarkConfig

Trait BenchmarkConfig 

pub trait BenchmarkConfig {
    // Required methods
    fn metadata(&self) -> &BenchmarkMetadata;
    fn load(&self, source: &Path, path: &Path) -> Result<(), Box<dyn Error>>;

    // Provided method
    fn validate(&self, path: &Path) -> Result<(), Box<dyn Error>> { ... }
}
Trait that each benchmark must implement to define its metadata, loading logic, and validation.

Required Methods

fn metadata(&self) -> &BenchmarkMetadata

Returns the static metadata for this benchmark.

fn load(&self, source: &Path, path: &Path) -> Result<(), Box<dyn Error>>

Loads and transforms the raw downloaded dataset from source into the benchmark directory at path.

Provided Methods

fn validate(&self, path: &Path) -> Result<(), Box<dyn Error>>

Validates that all expected data and query files exist under path. Uses the paths declared in SubTask definitions.

Implementors