base_cache_dir

Function base_cache_dir 

pub fn base_cache_dir() -> Result<PathBuf, BenchError>
Returns the base cache directory for kermit benchmarks ($XDG_CACHE_HOME/kermit/benchmarks on Linux).

Errors

Returns BenchError::NoCacheDir if the platform cache directory cannot be determined.