relation_cache_path

Function relation_cache_path 

pub fn relation_cache_path(
    benchmark_name: &str,
    relation_name: &str,
) -> Result<PathBuf, BenchError>
Returns the expected path for a cached relation file.

Errors

Returns BenchError::NoCacheDir if the platform cache directory cannot be determined.